@@ -14,7 +14,7 @@ from mautrix.types import (StateEvent, EventType, StateEventContent, EventID, Co
                            RoomTopicStateEventContent, PowerLevelStateEventContent,
                            RoomPinnedEventsStateEventContent, Membership, Member)
 from mautrix.client import ClientAPI, StoreUpdatingAPI
-from mautrix.errors import MForbidden, MBadState, MatrixRequestError, IntentError
+from mautrix.errors import MForbidden, MBadState, MatrixRequestError, IntentError, MNotFound
 from mautrix.util.logging import TraceLogger
 
 from ..state_store import ASStateStore
@@ -32,6 +32,9 @@ def quote(*args, **kwargs):
     return urllib_quote(*args, **kwargs, safe="")
 
 
+_bridgebot = object()
+
+
 ENSURE_REGISTERED_METHODS = (
     # Room methods
     ClientAPI.create_room, ClientAPI.add_room_alias, ClientAPI.remove_room_alias,
@@ -41,6 +44,8 @@ ENSURE_REGISTERED_METHODS = (
     ClientAPI.search_users, ClientAPI.set_displayname, ClientAPI.set_avatar_url,
 
     ClientAPI.upload_media,
+
+    ClientAPI.send_receipt, ClientAPI.set_fully_read_marker,
 )
 
 ENSURE_JOINED_METHODS = (
@@ -50,7 +55,6 @@ ENSURE_JOINED_METHODS = (
     ClientAPI.get_event, ClientAPI.get_state_event, ClientAPI.get_state,
     ClientAPI.get_joined_members, ClientAPI.get_messages, ClientAPI.send_state_event,
     ClientAPI.send_message_event, ClientAPI.redact,
-    ClientAPI.send_receipt, ClientAPI.set_fully_read_marker,
 )
 
 
@@ -191,7 +195,10 @@ class IntentAPI(StoreUpdatingAPI):
             levels = await self.state_store.get_power_levels(room_id)
             if levels:
                 return levels
-        levels = await self.get_state_event(room_id, EventType.ROOM_POWER_LEVELS)
+        try:
+            levels = await self.get_state_event(room_id, EventType.ROOM_POWER_LEVELS)
+        except MNotFound:
+            levels = PowerLevelStateEventContent()
         await self.state_store.set_power_levels(room_id, levels)
         return levels
 
@@ -205,7 +212,10 @@ class IntentAPI(StoreUpdatingAPI):
 
     async def get_pinned_messages(self, room_id: RoomID) -> List[EventID]:
         await self.ensure_joined(room_id)
-        content = await self.get_state_event(room_id, EventType.ROOM_PINNED_EVENTS)
+        try:
+            content = await self.get_state_event(room_id, EventType.ROOM_PINNED_EVENTS)
+        except MNotFound:
+            return []
         return content["pinned"]
 
     def set_pinned_messages(self, room_id: RoomID, events: List[EventID], **kwargs
@@ -273,7 +283,7 @@ class IntentAPI(StoreUpdatingAPI):
     async def send_state_event(self, room_id: RoomID, event_type: EventType,
                                content: Union[StateEventContent, Dict],
                                state_key: Optional[str] = "", **kwargs) -> EventID:
-        await self._ensure_has_power_level_for(room_id, event_type)
+        await self._ensure_has_power_level_for(room_id, event_type, state_key=state_key)
         return await super().send_state_event(room_id, event_type, content, state_key, **kwargs)
 
     async def get_room_members(self, room_id: RoomID,
@@ -310,30 +320,35 @@ class IntentAPI(StoreUpdatingAPI):
     # endregion
     # region Ensure functions
 
-    async def ensure_joined(self, room_id: RoomID, ignore_cache: bool = False) -> bool:
+    async def ensure_joined(self, room_id: RoomID, ignore_cache: bool = False,
+                            bot: Optional['IntentAPI'] = _bridgebot) -> bool:
         if not room_id:
             raise ValueError("Room ID not given")
         if not ignore_cache and await self.state_store.is_joined(room_id, self.mxid):
             return False
+        if bot is _bridgebot:
+            bot = self.bot
+        if bot is self:
+            bot = None
         await self.ensure_registered()
         try:
             await self.join_room(room_id, max_retries=0)
             await self.state_store.joined(room_id, self.mxid)
         except MForbidden as e:
-            if not self.bot:
+            if not bot:
                 raise IntentError(f"Failed to join room {room_id} as {self.mxid}") from e
             try:
-                await self.bot.invite_user(room_id, self.mxid)
+                await bot.invite_user(room_id, self.mxid)
                 await self.join_room(room_id, max_retries=0)
                 await self.state_store.joined(room_id, self.mxid)
             except MatrixRequestError as e2:
                 raise IntentError(f"Failed to join room {room_id} as {self.mxid}") from e2
         except MBadState as e:
-            if not self.bot:
+            if not bot:
                 raise IntentError(f"Failed to join room {room_id} as {self.mxid}") from e
             try:
-                await self.bot.unban_user(room_id, self.mxid)
-                await self.bot.invite_user(room_id, self.mxid)
+                await bot.unban_user(room_id, self.mxid)
+                await bot.invite_user(room_id, self.mxid)
                 await self.join_room(room_id, max_retries=0)
                 await self.state_store.joined(room_id, self.mxid)
             except MatrixRequestError as e2:
@@ -359,13 +374,18 @@ class IntentAPI(StoreUpdatingAPI):
                 # return
         await self.state_store.registered(self.mxid)
 
-    async def _ensure_has_power_level_for(self, room_id: RoomID, event_type: EventType) -> None:
+    async def _ensure_has_power_level_for(self, room_id: RoomID, event_type: EventType,
+                                          state_key: str = "") -> None:
         if not room_id:
             raise ValueError("Room ID not given")
         elif not event_type:
             raise ValueError("Event type not given")
 
+        if event_type == EventType.ROOM_MEMBER:
+            # TODO: if state_key doesn't equal self.mxid, check invite/kick/ban permissions
+            return
         if not await self.state_store.has_power_levels_cached(room_id):
+            # TODO add option to not try to fetch power levels from server
             await self.get_power_levels(room_id, ignore_cache=True)
         if not await self.state_store.has_power_level(room_id, self.mxid, event_type):
             # TODO implement something better
