@@ -16,6 +16,7 @@ from mautrix.util.logging import TraceLogger
 from .api import AppServiceAPI, IntentAPI
 from .state_store import ASStateStore, FileASStateStore
 from .as_handler import AppServiceServerMixin
+from ..api import HTTPAPI
 
 try:
     import ssl
@@ -37,6 +38,7 @@ class AppService(AppServiceServerMixin):
     as_token: str
     hs_token: str
     bot_mxid: UserID
+    default_ua: str
     real_user_content_key: str
     state_store: ASStateStore
 
@@ -59,7 +61,7 @@ class AppService(AppServiceServerMixin):
                  query_user: QueryFunc = None, query_alias: QueryFunc = None,
                  real_user_content_key: Optional[str] = "net.maunium.appservice.puppet",
                  state_store: ASStateStore = None, aiohttp_params: Dict = None,
-                 ephemeral_events: bool = False) -> None:
+                 ephemeral_events: bool = False, default_ua: str = HTTPAPI.default_ua) -> None:
         super().__init__(ephemeral_events=ephemeral_events)
         self.server = server
         self.domain = domain
@@ -70,6 +72,7 @@ class AppService(AppServiceServerMixin):
         self.as_token = as_token
         self.hs_token = hs_token
         self.bot_mxid = UserID(f"@{bot_localpart}:{domain}")
+        self.default_ua = default_ua
         self.real_user_content_key: str = real_user_content_key
         if not state_store:
             file = state_store if isinstance(state_store, str) else "mx-state.json"
@@ -124,7 +127,9 @@ class AppService(AppServiceServerMixin):
         self.log.debug(f"Starting appservice web server on {host}:{port}")
         if self.server.startswith("https://") and not self.verify_ssl:
             connector = aiohttp.TCPConnector(verify_ssl=False)
-        self._http_session = aiohttp.ClientSession(loop=self.loop, connector=connector)
+        default_headers = {"User-Agent": self.default_ua}
+        self._http_session = aiohttp.ClientSession(loop=self.loop, connector=connector,
+                                                   headers=default_headers)
         self._intent = AppServiceAPI(base_url=self.server, bot_mxid=self.bot_mxid, log=self.log,
                                      token=self.as_token, state_store=self.state_store,
                                      real_user_content_key=self.real_user_content_key,
