@@ -8,13 +8,15 @@ import logging
 import asyncio
 import os.path
 import time
+import sys
 
 from yarl import URL
 
 from mautrix.types import (EventID, RoomID, UserID, Event, EventType, MessageEvent, MessageType,
                            MessageEventContent, StateEvent, Membership, MemberStateEventContent,
                            PresenceEvent, TypingEvent, ReceiptEvent, TextMessageEventContent,
-                           EncryptedEvent, ReceiptType, SingleReceiptEventContent)
+                           EncryptedEvent, ReceiptType, SingleReceiptEventContent, StateUnsigned,
+                           MediaRepoConfig)
 from mautrix.errors import IntentError, MatrixError, MForbidden, DecryptionError, SessionNotFound
 from mautrix.appservice import AppService
 from mautrix.util.logging import TraceLogger
@@ -44,6 +46,7 @@ class BaseMatrixHandler:
     config: 'BaseBridgeConfig'
     bridge: 'Bridge'
     e2ee: Optional[EncryptionManager]
+    media_config: MediaRepoConfig
 
     user_id_prefix: str
     user_id_suffix: str
@@ -54,6 +57,7 @@ class BaseMatrixHandler:
         self.config = bridge.config
         self.bridge = bridge
         self.commands = command_processor or CommandProcessor(bridge=bridge)
+        self.media_config = MediaRepoConfig(upload_size=50 * 1024 * 1024)
         self.az.matrix_event_handler(self.int_handle_event)
 
         self.e2ee = None
@@ -89,7 +93,7 @@ class BaseMatrixHandler:
                 await self.az.intent.whoami()
                 break
             except MForbidden as e:
-                if "has not registered this user" in e.message and not tried_to_register:
+                if not tried_to_register:
                     self.log.debug("Whoami endpoint returned M_FORBIDDEN, "
                                    "trying to register bridge bot before retrying...")
                     await self.az.intent.ensure_registered()
@@ -103,6 +107,10 @@ class BaseMatrixHandler:
                     await asyncio.sleep(10)
                 else:
                     raise
+        try:
+            self.media_config = await self.az.intent.get_media_repo_config()
+        except Exception:
+            self.log.warning("Failed to fetch media repo config", exc_info=True)
 
     async def init_as_bot(self) -> None:
         self.log.debug("Initializing appservice bot")
@@ -124,11 +132,9 @@ class BaseMatrixHandler:
     async def init_encryption(self) -> None:
         if self.e2ee:
             if not await self.e2ee.check_server_support():
-                # Element iOS is broken, so the devs decided to break Synapse as well, which means
-                # there's no reliable way to check if appservice login is supported.
-                # Print a warning in the logs, then try to log in anyway and hope for the best.
-                self.log.warning("Encryption enabled in config, but homeserver does not advertise "
-                                 "appservice login")
+                self.log.critical("Encryption enabled in config, but homeserver does not advertise "
+                                  "appservice login")
+                sys.exit(30)
             await self.e2ee.start()
 
     @staticmethod
@@ -349,6 +355,9 @@ class BaseMatrixHandler:
                                          f"\u26a0 Your message was not bridged: {error}")
 
     async def handle_encrypted(self, evt: EncryptedEvent) -> None:
+        if not self.e2ee:
+            await self.handle_encrypted_unsupported(evt)
+            return
         try:
             decrypted = await self.e2ee.decrypt(evt, wait_session_timeout=5)
         except SessionNotFound as e:
@@ -360,6 +369,12 @@ class BaseMatrixHandler:
         else:
             await self.int_handle_event(decrypted)
 
+    async def handle_encrypted_unsupported(self, evt: EncryptedEvent) -> None:
+        self.log.debug("Got encrypted message %s from %s, but encryption is not enabled",
+                       evt.event_id, evt.sender)
+        await self.az.intent.send_notice(evt.room_id, "🔒️ This bridge has not been configured "
+                                                      "to support encryption")
+
     async def _handle_encrypted_wait(self, evt: EncryptedEvent, err: SessionNotFound, wait: int
                                      ) -> None:
         self.log.warning(f"Didn't find session {err.session_id}, waiting even longer")
@@ -373,6 +388,7 @@ class BaseMatrixHandler:
             try:
                 decrypted = await self.e2ee.decrypt(evt, wait_session_timeout=0)
             except DecryptionError as e:
+                self.log.warning(f"Didn't get {err.session_id}, giving up on {evt.event_id}")
                 msg = f"\u26a0 Your message was not bridged: {e}"
             else:
                 await self.az.intent.redact(evt.room_id, event_id)
@@ -406,7 +422,8 @@ class BaseMatrixHandler:
 
         if evt.type == EventType.ROOM_MEMBER:
             evt: StateEvent
-            prev_content = evt.unsigned.prev_content or MemberStateEventContent()
+            unsigned = evt.unsigned or StateUnsigned()
+            prev_content = unsigned.prev_content or MemberStateEventContent()
             prev_membership = prev_content.membership if prev_content else Membership.JOIN
             if evt.content.membership == Membership.INVITE:
                 await self.int_handle_invite(evt.room_id, UserID(evt.state_key), evt.sender,
@@ -441,7 +458,7 @@ class BaseMatrixHandler:
             if evt.type != EventType.ROOM_MESSAGE:
                 evt.content.msgtype = MessageType(str(evt.type))
             await self.handle_message(evt.room_id, evt.sender, evt.content, evt.event_id)
-        elif evt.type == EventType.ROOM_ENCRYPTED and self.e2ee:
+        elif evt.type == EventType.ROOM_ENCRYPTED:
             await self.handle_encrypted(evt)
         elif evt.type == EventType.ROOM_ENCRYPTION:
             await self.handle_encryption(evt)
