@@ -4,6 +4,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 from typing import Optional, Dict, Any, List, TYPE_CHECKING
+from collections import defaultdict
 from abc import ABC, abstractmethod
 import asyncio
 import logging
@@ -24,6 +25,7 @@ if TYPE_CHECKING:
 
 class BasePortal(ABC):
     log: TraceLogger = logging.getLogger("mau.portal")
+    _async_get_locks: Dict[Any, asyncio.Lock] = defaultdict(lambda: asyncio.Lock())
     az: AppService
     matrix: 'BaseMatrixHandler'
     bridge: 'Bridge'
@@ -81,8 +83,9 @@ class BasePortal(ABC):
             event_type, content = await call_with_net_retry(self.matrix.e2ee.encrypt, self.mxid,
                                                             event_type, content,
                                                             _action="encrypt message")
+        txn_id = intent.api.get_txn_id()
         return await call_with_net_retry(intent.send_message_event, self.mxid, event_type, content,
-                                         **kwargs, _action="send message")
+                                         txn_id=txn_id, **kwargs, _action="send message")
 
     @property
     @abstractmethod
