@@ -4,6 +4,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 from typing import Dict, Any, Optional, List, TYPE_CHECKING
+from collections import defaultdict
 from abc import ABC, abstractmethod
 import logging
 import asyncio
@@ -20,11 +21,12 @@ from .portal import BasePortal
 if TYPE_CHECKING:
     from .bridge import Bridge
 
-AsmuxPath = UnstableClientPath["net.maunium.asmux"]
+AsmuxPath = UnstableClientPath["com.beeper.asmux"]
 
 
 class BaseUser(ABC):
     log: TraceLogger = logging.getLogger("mau.user")
+    _async_get_locks: Dict[Any, asyncio.Lock] = defaultdict(lambda: asyncio.Lock())
     az: AppService
     bridge: 'Bridge'
     loop: asyncio.AbstractEventLoop
@@ -76,7 +78,10 @@ class BaseUser(ABC):
                                             content=dms, headers={"X-Asmux-Auth": self.az.as_token})
         else:
             async with self.dm_update_lock:
-                current_dms = await puppet.intent.get_account_data(EventType.DIRECT)
+                try:
+                    current_dms = await puppet.intent.get_account_data(EventType.DIRECT)
+                except MNotFound:
+                    current_dms = {}
                 if replace:
                     # Filter away all existing DM statuses with bridge users
                     current_dms = {user: rooms for user, rooms in current_dms.items()
