@@ -45,4 +45,4 @@ from .auth import (LoginType, UserIdentifierType, MatrixUserIdentifier, ThirdPar
 from .crypto import UnsignedDeviceInfo, DeviceKeys, ClaimKeysResponse, QueryKeysResponse
 from .media import MediaRepoConfig, MXOpenGraph, OpenGraphVideo, OpenGraphImage, OpenGraphAudio
 from .util import (Obj, Lst, SerializerError, Serializable, SerializableEnum, SerializableAttrs,
-                   serializer, deserializer)
+                   serializer, deserializer, ExtensibleEnum)
